SwitcherRadius class

Constructors

SwitcherRadius({double bottomLeft = 0.0, double bottomRight = 0.0, double topLeft = 0.0, double topRight = 0.0})
const
SwitcherRadius.all({required double radius})
const

Properties

bottomLeft → double
final
bottomRight → double
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeft → double
final
topRight → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited